@@ -28,10 +28,12 @@ File = file.File  # TODO: remove, should be LocalTarget
 LocalTarget = File
 Parameter = parameter.Parameter
 RemoteScheduler = rpc.RemoteScheduler
+RPCError = rpc.RPCError
 
 expose = interface.expose
 expose_main = interface.expose_main
 run = interface.run
+build = interface.build
 
 # TODO: how can we get rid of these?
 DateHourParameter = parameter.DateHourParameter
